@@ -18,6 +18,9 @@ test_that("construct_cont works", {
   testthat::expect_null(cont3[[2]])
   testthat::expect_null(cont3[[3]])
   
+  ## Don't run on CRAN servers due to ongoing internet connectivity issues
+  if(!is_gha()) testthat::skip_if_offline()
+  
   cont4 <- construct_cont(default_tag = "release",
                           default_registry = "ghcr.io",
                           run_check_cont = TRUE) 
